@@ -4,7 +4,9 @@ from pyspark.conf import SparkConf
 
 
 class SparkManager:
-    def set_spark_config(self, name, aws_access_key_id=None, aws_secret_access_key=None):
+    def set_spark_config(
+        self, name, aws_access_key_id=None, aws_secret_access_key=None
+    ):
         # Create a SparkConf object and set the application name
         config = SparkConf().setAppName(name)
 
