@@ -47,7 +47,7 @@ class PathParams:
             ), "Couldn't find `schema_path` in path input"
 
     @classmethod
-    def from_dict(cls, data: dict[str, str]):
+    def from_dict(cls, data: dict):
         instance = cls(
             env=data["env"],
             bucket_name=data["bucket_name"],
@@ -393,6 +393,12 @@ class Table:
         # Split the partition string into individual partitions
         partitions = self.path.partition.split("/")
 
+        # Write the schema
+        try:
+            self.write_schema(df)
+        except Exception as e:
+            raise ValueError("Error writing schema: {}".format(str(e)))
+
         # Check if the table should be saved partitioned
         if partitions != [""]:
             for part in partitions:
@@ -405,8 +411,4 @@ class Table:
             # Write the table without partition
             df.write.mode("append").format(file_type).save(path)
 
-        # Write the schema
-        try:
-            self.write_schema(df)
-        except Exception as e:
-            raise ValueError("Error writing schema: {}".format(str(e)))
+        
